-- MountFeedTimer(MFT) by @aTo
-- version 1.1.4 05/23/2014
-- Main config settings
local LMP = LibStub:GetLibrary("LibMediaProvider-1.0")
local LAM = LibStub:GetLibrary("LibAddonMenu-2.0")
local fontList = LMP:List('font')
local fontStyles = {"normal", "outline", "thick-outline", "shadow", "soft-shadow-thick", "soft-shadow-thin"}

MFT = {
	name = "MountFeedTimer",
	svName = "MountFeedTimer_SavedVariables",
	svDefaults = {
		lock = true,
		scale = 1,
		alpha = 1,
		font = "Univers 67",
		style = "soft-shadow-thin",
		size = 18,
		Hide_Type = "Always",
		autocolor = true,
		timer_format = "hh:mm:ss",
		title = "Feed timer",
		offset = {
				X = 800,
				Y = 400,
				},
		Color = {
				r = 1,
				g = 1,
				b = 1,
				a = 1 }
	}
}

local panelData = {
	type = "panel",
	name = "Mount Feed Timer",
	displayName = "|c96FF00Mount Feed Timer|r Settings"
}

local optionsTable = {

	-- Main settings
	{
		type = "header",
		name = "|c96FF00Options|r"
	},
	{
		type = "checkbox",
		name = "Unlock windows",
		tooltip = "Toggle lock on/off",
		getFunc = function() return MFT.SV.lock end,
		setFunc = SetMFTLock
	},
	{
		type = "dropdown",
		name = "Display when",
		tooltip = "Display when?",
		choices = {"Always", "Hide in menus","Menus only", "Timer < 1 hour", "Toggle keybind"},
		getFunc = function() return MFT.SV.Hide_Type end,
		setFunc = SetMFTHideMenu,
		warning = "Keybind doesn't work with french client (german?)"
	},
	{
		type = "dropdown",
		name = "Title",
		tooltip = "Title choice",
		choices = {"Feed timer", "Mount name"},
		getFunc = function() return MFT.SV.title end,
		setFunc = SetMFTtitle
	},
	{
		type = "dropdown",
		name = "Timer format",
		tooltip = "Timer format",
		choices = {"hh:mm:ss", "hh:mm"},
		getFunc = function() return MFT.SV.timer_format end,
		setFunc = SetMFTtimer_format
	},
	{
		type = "dropdown",
		name = "Font",
		tooltip = "Set the font for the timer",
		choices = fontList,
		getFunc = function() return MFT.SV.font end,
		setFunc = MFT_SetFont,
		warning = "Some fonts do not appear to be supported"
	},
	{
		type = "dropdown",
		name = "Set the font style for the timer",
		tooltip = "Font style",
		choices = fontStyles,
		getFunc = function() return MFT.SV.style end,
		setFunc = MFT_SetStyle,
		warning = "Some styles are not supported by some fonts"
	},
	{
		type = "slider",
		name = "Font size",
		tooltip = "Change the font size of the timer",
		min = 10,
		max = 30,
		step = 1,
		getFunc = function() return MFT.SV.size end,
		setFunc = MFT_SetSize
	},
	{
		type = "checkbox",
		name = "Auto color",
		tooltip = "Toggle lock on/off",
		getFunc = function() return MFT.SV.autocolor end,
		setFunc = SetMFTAutocolor
	},
	{
		type = "colorpicker",
		name = "Custom Color",
		tooltip = "Select the text color",
		getFunc = GetMFTColor,
		setFunc = SetMFTColor,
		warning = "Will require a UI reload"
	},
}

function OnAddonLoaded(eventCode, name)
	if (name == MFT.name) then
		MFT.Init_done = false
		MFT.SV = ZO_SavedVars:New(MFT.svName, 2, nil, MFT.svDefaults, nil)
		
		ZO_CreateStringId("SI_BINDING_NAME_TOGGLE_MFT", "Toggle Mount feed timer")

		LAM:RegisterAddonPanel("MFT_OptionsPanel", panelData);
		LAM:RegisterOptionControls("MFT_OptionsPanel", optionsTable);

		

		MFT_create_windows()
		MFT.Init_done = true
	end
end

EVENT_MANAGER:RegisterForEvent(MFT.name, EVENT_ADD_ON_LOADED, OnAddonLoaded)


local bt= {}
function BufferReached( BufferName, ThrottleInSeconds ) 
	if not BufferName then return end
	local ct, ThrottleInSeconds = GetGameTimeMilliseconds(), ((ThrottleInSeconds or 3) * 1000)
	--d( "test "..ThrottleInSeconds )
	if not bt[BufferName] then bt[BufferName] = ct end
	if (ct - bt[BufferName]) >= ThrottleInSeconds
	then bt[BufferName] = ct; return true;
	else return false; end
end

local function Timeconvert(InitTimer)
		local timeinsec = InitTimer /1000
		local heure = math.floor(timeinsec/3600)
		local reste = timeinsec - (heure*3600)
		local minute = math.floor(reste/60)
		local seconde = reste -(minute*60)
		if (MFT.SV.timer_format == "hh:mm:ss") then
			return string.format("%02d:%02d:%02d", heure, minute, seconde)
		elseif (MFT.SV.timer_format == "hh:mm") then
			return string.format("%02d:%02d", heure, minute)
		end
end

local function mount_feed_timer()
	if (IsStableSlotEmpty(1) == false) then
		local temp_timer ={}
		local NumStableSlots = GetNumStableSlots() + 1
		local minitimer = 99999999999999999999999
		local msg = "error"

		for nb_slots = 1, NumStableSlots, 1 do
			temp_timer[nb_slots], _ = GetTimeUntilMountCanBeFed(nb_slots)

			if (minitimer ~= nil and temp_timer[nb_slots] ~= nil and minitimer > temp_timer[nb_slots]) then
				minitimer = temp_timer[nb_slots]
				minislot = nb_slots
			end
		end

		local name,  _,  _,  _,  _,  _ = GetStableSlotInfo(minislot)
				
		if (MFT.SV.title == "Feed timer") then 
			 MFT_titre = "Feed timer"
		elseif (MFT.SV.title == "Mount name") then
			 MFT_titre = name
		end
		


		if (minitimer == 99999999999999999999999) then
			msg = MFT_titre..": lvl max"
		else
			msg = MFT_titre..": "..Timeconvert(minitimer)
		end

		MFT_WD:SetFont(("%s|%s|%s"):format(LMP:Fetch('font', MFT.SV.font), MFT.SV.size, MFT.SV.style))
		MFT_WD:SetText(msg)
		MFT_autocolor(MFT.SV.autocolor,minitimer)
		toggleMFT(minitimer)
	end
end




function MFT_create_windows()
		MFT_tlw = WINDOW_MANAGER:CreateTopLevelWindow("MFT_tlw")
		MFT_tlw:SetDimensions(240,25)
		MFT_tlw:SetHidden(false)
		MFT_tlw:SetClampedToScreen(false)
		MFT_tlw:SetMovable(MFT.SV.lock)
		MFT_tlw:SetMouseEnabled(true)
		MFT_tlw:SetDrawLayer(1)
		MFT_tlw:SetScale(1)
		MFT_tlw:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, MFT.SV.offset.X, MFT.SV.offset.Y)
		MFT_tlw:SetHandler( "OnMouseUp" , function(self) MFT_save_position() end)

		--MFT_BD = WINDOW_MANAGER:CreateControlFromVirtual(MFT.name.."_Windows_BD",MFT_tlw, "ZO_DefaultBackdrop")
		
		MFT_WD = WINDOW_MANAGER:CreateControl("MFT_WD",MFT_tlw,CT_LABEL)
		MFT_WD:SetHidden(false)
		MFT_WD:SetColor(MFT.SV.Color.r, MFT.SV.Color.g, MFT.SV.Color.b, MFT.SV.Color.a)
		MFT_WD:SetAlpha(1)
		MFT_WD:SetAnchorFill(MFT_tlw)
end

function MountFeedTimerUpdate()
	if not BufferReached(MFT.name, 1) then return; end
	if not MFT.Init_done then return; end
	mount_feed_timer()
end



